@@ -23,6 +23,7 @@ import traceback
 
 from cliff import app
 from cliff import command
+from cliff import commandmanager
 from cliff import complete
 from cliff import help
 from oslo_utils import importutils
@@ -30,7 +31,6 @@ from oslo_utils import strutils
 
 from osc_lib.cli import client_config as cloud_config
 from osc_lib import clientmanager
-from osc_lib.command import commandmanager
 from osc_lib.command import timing
 from osc_lib import exceptions as exc
 from osc_lib.i18n import _
@@ -495,6 +495,10 @@ class OpenStackShell(app.App):
     def clean_up(self, cmd, result, err):
         self.log.debug('clean_up %s: %s', cmd.__class__.__name__, err or '')
 
+        # Close SDK connection if available to have proper cleanup there
+        if self.client_manager.sdk_connection:
+            self.client_manager.sdk_connection.close()
+
         # Process collected timing data
         if self.options.timing:
             # Get session data
